==> ginkgo-hpc-docs-1.8.0-1-x86_64.pkg.tar.zst: usr/share/doc/ginkgo-hpc/html/search/all_8.js <==
var searchData=
[
  ['baddimension_0',['BadDimension',['../classgko_1_1BadDimension.html',1,'gko::BadDimension'],['../classgko_1_1BadDimension.html#a774454482004beac61bd983f74f446c3',1,'gko::BadDimension::BadDimension()']]],
  ['baseline_1',['baseline',['../structgko_1_1stop_1_1ResidualNorm_1_1parameters__type.html#a845b588b794200edea462bccb10bf2e4',1,'gko::stop::ResidualNorm::parameters_type::baseline'],['../structgko_1_1stop_1_1ImplicitResidualNorm_1_1parameters__type.html#a6461458a3f3de03615d338b9122981c7',1,'gko::stop::ImplicitResidualNorm::parameters_type::baseline']]],
  ['batch_5fdim_2',['batch_dim',['../structgko_1_1batch__dim.html',1,'gko::batch_dim&lt; Dimensionality, DimensionType &gt;'],['../structgko_1_1batch__dim.html#a9ad0e2ce59184e0969c4cfbbccd16fbc',1,'gko::batch_dim::batch_dim()'],['../structgko_1_1batch__dim.html#a084efe247f49ff54a4156858991a2eb5',1,'gko::batch_dim::batch_dim(const size_type num_batch_items, const dim&lt; dimensionality, dimension_type &gt; &amp;common_size)']]],
  ['batch_5fdim_3c_202_20_3e_3',['batch_dim&lt; 2 &gt;',['../structgko_1_1batch__dim.html',1,'gko']]],
  ['batch_5flinop_5ffactory_5fevents_5fmask_4',['batch_linop_factory_events_mask',['../classgko_1_1log_1_1Logger.html#a3a6ea4ed2e7b25cd1ca869e4d3bdb07a',1,'gko::log::Logger']]],
  ['batchcg_20in_20ginkgo_5',['Example: using BatchCG in Ginkgo',['../classgko_1_1batch_1_1BatchLinOpFactory.html#autotoc_md72',1,'']]],
  ['batchconvergence_6',['BatchConvergence',['../classgko_1_1batch_1_1log_1_1BatchConvergence.html',1,'gko::batch::log']]],
  ['batched_20linear_20operator_20as_20a_20concept_7',['Batched Linear operator as a concept',['../group__BatchLinOp.html#batch_linop_concept',1,'']]],
  ['batched_20solver_20program_8',['The batched-solver program',['../batched_solver.html',1,'']]],
  ['batchlinop_9',['BatchLinOp',['../classgko_1_1batch_1_1BatchLinOp.html',1,'gko::batch::BatchLinOp'],['../group__BatchLinOp.html',1,'BatchLinOp']]],
  ['batchlinopfactory_10',['BatchLinOpFactory',['../classgko_1_1batch_1_1BatchLinOpFactory.html',1,'gko::batch']]],
  ['batchsolver_11',['BatchSolver',['../classgko_1_1batch_1_1solver_1_1BatchSolver.html',1,'gko::batch::solver']]],
  ['begin_12',['begin',['../structgko_1_1span.html#a54ff06eda27a98b62e83c7e9e7b6dcd7',1,'gko::span']]],
  ['benchmark_20options_13',['7: Available benchmark options',['../benchmarking_ginkgo.html#autotoc_md17',1,'']]],
  ['benchmarking_20overview_14',['4: Benchmarking overview',['../benchmarking_ginkgo.html#autotoc_md14',1,'']]],
  ['benchmarks_15',['Running the benchmarks',['../benchmarking_ginkgo.html',1,'']]],
  ['benchmarks_20manually_16',['3: Running benchmarks manually',['../benchmarking_ginkgo.html#autotoc_md13',1,'']]],
  ['best_20practice_20guidelines_17',['1: Ginkgo setup and best practice guidelines',['../benchmarking_ginkgo.html#autotoc_md11',1,'']]],
  ['bicg_18',['Bicg',['../classgko_1_1solver_1_1Bicg.html',1,'gko::solver']]],
  ['bicgstab_19',['Bicgstab',['../classgko_1_1batch_1_1solver_1_1Bicgstab.html',1,'gko::batch::solver::Bicgstab&lt; ValueType &gt;'],['../classgko_1_1solver_1_1Bicgstab.html',1,'gko::solver::Bicgstab&lt; ValueType &gt;']]],
  ['bind_5fto_5fcore_20',['bind_to_core',['../classgko_1_1machine__topology.html#a9a18cb07c0fcc866997c727abfac52d9',1,'gko::machine_topology']]],
  ['bind_5fto_5fcores_21',['bind_to_cores',['../classgko_1_1machine__topology.html#aa63dcb3e4080720109cf9e48bfc97f42',1,'gko::machine_topology']]],
  ['bind_5fto_5fpu_22',['bind_to_pu',['../classgko_1_1machine__topology.html#a9788d302561048fa91257f71ca9fa4be',1,'gko::machine_topology']]],
  ['bind_5fto_5fpus_23',['bind_to_pus',['../classgko_1_1machine__topology.html#a6c1579ec42001ec51ecb7102578bd932',1,'gko::machine_topology']]],
  ['bitwise_5fand_24',['bitwise_and',['../structgko_1_1accessor_1_1bitwise__and.html',1,'gko::accessor']]],
  ['bitwise_5fnot_25',['bitwise_not',['../structgko_1_1accessor_1_1bitwise__not.html',1,'gko::accessor']]],
  ['bitwise_5for_26',['bitwise_or',['../structgko_1_1accessor_1_1bitwise__or.html',1,'gko::accessor']]],
  ['bitwise_5fxor_27',['bitwise_xor',['../structgko_1_1accessor_1_1bitwise__xor.html',1,'gko::accessor']]],
  ['block_5fat_28',['block_at',['../classgko_1_1BlockOperator.html#a8ae64878f419a1719010efa49c660279',1,'gko::BlockOperator']]],
  ['block_5finterleaved_5fstorage_5fscheme_29',['block_interleaved_storage_scheme',['../structgko_1_1preconditioner_1_1block__interleaved__storage__scheme.html',1,'gko::preconditioner']]],
  ['block_5finterleaved_5fstorage_5fscheme_3c_20index_5ftype_20_3e_30',['block_interleaved_storage_scheme&lt; index_type &gt;',['../structgko_1_1preconditioner_1_1block__interleaved__storage__scheme.html',1,'gko::preconditioner']]],
  ['block_5foffset_31',['block_offset',['../structgko_1_1preconditioner_1_1block__interleaved__storage__scheme.html#ada09b37f171d433cc74818961fc6eccc',1,'gko::preconditioner::block_interleaved_storage_scheme']]],
  ['block_5fpointers_32',['block_pointers',['../structgko_1_1batch_1_1preconditioner_1_1Jacobi_1_1parameters__type.html#afd91913f62dc55b7173d41f6d6144961',1,'gko::batch::preconditioner::Jacobi::parameters_type::block_pointers'],['../structgko_1_1preconditioner_1_1Jacobi_1_1parameters__type.html#ad90b07202f15b6cd5c649f6b61480053',1,'gko::preconditioner::Jacobi::parameters_type::block_pointers']]],
  ['blockjacobi_20program_33',['The adaptiveprecision-blockjacobi program',['../adaptiveprecision_blockjacobi.html',1,'']]],
  ['blockoperator_34',['BlockOperator',['../classgko_1_1BlockOperator.html',1,'gko::BlockOperator'],['../classgko_1_1BlockOperator.html#acb8ff1788a332231a3e9f8199dec0d03',1,'gko::BlockOperator::BlockOperator(const BlockOperator &amp;other)'],['../classgko_1_1BlockOperator.html#a4066b33a9d42462429c76eea3f9532c1',1,'gko::BlockOperator::BlockOperator(BlockOperator &amp;&amp;other) noexcept']]],
  ['blocksizeerror_35',['BlockSizeError',['../classgko_1_1BlockSizeError.html',1,'gko::BlockSizeError&lt; IndexType &gt;'],['../classgko_1_1BlockSizeError.html#a861999cfafdd726814ef4bcd06734bd7',1,'gko::BlockSizeError::BlockSizeError()']]],
  ['both_5ffactors_36',['both_factors',['../structgko_1_1factorization_1_1Ic_1_1parameters__type.html#afb4c7814334072ab39c2e2b04925cdc4',1,'gko::factorization::Ic::parameters_type::both_factors'],['../structgko_1_1factorization_1_1ParIc_1_1parameters__type.html#abfa3c5afbc05b7c25b09ae225e6c966a',1,'gko::factorization::ParIc::parameters_type::both_factors']]],
  ['broadcast_37',['broadcast',['../classgko_1_1experimental_1_1mpi_1_1communicator.html#a95ea693d1ddc249215968d378e80dcc7',1,'gko::experimental::mpi::communicator']]],
  ['build_38',['build',['../classgko_1_1experimental_1_1factorization_1_1Cholesky.html#a154cada7f11335b0148b946e3b6ad85f',1,'gko::experimental::factorization::Cholesky::build()'],['../classgko_1_1experimental_1_1factorization_1_1Lu.html#a61cd8064ed1566c54912183bfeae5e5e',1,'gko::experimental::factorization::Lu::build()'],['../classgko_1_1experimental_1_1reorder_1_1Amd.html#a03fa10a26c275d6aa5e87c97836f3169',1,'gko::experimental::reorder::Amd::build()'],['../classgko_1_1experimental_1_1reorder_1_1Mc64.html#acf4ff0eb6edb11ea44b9745ece9ded65',1,'gko::experimental::reorder::Mc64::build()'],['../classgko_1_1experimental_1_1reorder_1_1Rcm.html#a6be4bed40dd659bc915f4320c6f1ab81',1,'gko::experimental::reorder::Rcm::build()']]],
  ['build_5ffrom_5fcontiguous_39',['build_from_contiguous',['../classgko_1_1experimental_1_1distributed_1_1Partition.html#acbc987df113d50d6cdf6d6b605a15860',1,'gko::experimental::distributed::Partition']]],
  ['build_5ffrom_5fglobal_5fsize_5funiform_40',['build_from_global_size_uniform',['../classgko_1_1experimental_1_1distributed_1_1Partition.html#a54bfa82bec475057cba794814342505e',1,'gko::experimental::distributed::Partition']]],
  ['build_5ffrom_5fmapping_41',['build_from_mapping',['../classgko_1_1experimental_1_1distributed_1_1Partition.html#ad17d1164a99bca5df2d2ec0eb5d79c2f',1,'gko::experimental::distributed::Partition']]],
  ['build_5fpartition_5ffrom_5flocal_5frange_42',['build_partition_from_local_range',['../namespacegko_1_1experimental_1_1distributed.html#ae0368295654a9d8455731832a88ffc8c',1,'gko::experimental::distributed']]],
  ['build_5fpartition_5ffrom_5flocal_5fsize_43',['build_partition_from_local_size',['../namespacegko_1_1experimental_1_1distributed.html#a6fff69d2898fefe193012da079a2fef0',1,'gko::experimental::distributed']]],
  ['build_5fsmoother_44',['build_smoother',['../namespacegko_1_1solver.html#ac565c4b95ad0c67492073d993a9170cc',1,'gko::solver::build_smoother(std::shared_ptr&lt; const LinOpFactory &gt; factory, size_type iteration=1, ValueType relaxation_factor=0.9)'],['../namespacegko_1_1solver.html#aadb962ce0b5566e83fcdb22dda6e3cf8',1,'gko::solver::build_smoother(std::shared_ptr&lt; const LinOp &gt; solver, size_type iteration=1, ValueType relaxation_factor=0.9)']]],
  ['building_45',['Building',['../install_ginkgo.html#autotoc_md0',1,'']]],
  ['building_20ginkgo_20in_20windows_46',['Building Ginkgo in Windows',['../install_ginkgo.html#autotoc_md1',1,'']]],
  ['building_20ginkgo_20with_20hip_20support_47',['Building Ginkgo with HIP support',['../install_ginkgo.html#autotoc_md2',1,'']]],
  ['by_20clangformat_48',['Other Code Formatting not handled by ClangFormat',['../contributing_guidelines.html#autotoc_md45',1,'']]],
  ['byte_5fsize_49',['byte_size',['../namespacegko.html#acae2e648052ec788bd8ba9e0192652a6',1,'gko']]]
];

==> ginkgo-hpc-docs-1.9.0-1-x86_64.pkg.tar.zst: usr/share/doc/ginkgo-hpc/html/search/all_8.js <==
var searchData=
[
  ['baddimension_0',['BadDimension',['../classgko_1_1BadDimension.html',1,'gko::BadDimension'],['../classgko_1_1BadDimension.html#a774454482004beac61bd983f74f446c3',1,'gko::BadDimension::BadDimension()']]],
  ['baseline_1',['baseline',['../structgko_1_1stop_1_1ResidualNorm_1_1parameters__type.html#a845b588b794200edea462bccb10bf2e4',1,'gko::stop::ResidualNorm::parameters_type::baseline'],['../structgko_1_1stop_1_1ImplicitResidualNorm_1_1parameters__type.html#a6461458a3f3de03615d338b9122981c7',1,'gko::stop::ImplicitResidualNorm::parameters_type::baseline']]],
  ['batch_5fdim_2',['batch_dim',['../structgko_1_1batch__dim.html',1,'gko::batch_dim&lt; Dimensionality, DimensionType &gt;'],['../structgko_1_1batch__dim.html#a9ad0e2ce59184e0969c4cfbbccd16fbc',1,'gko::batch_dim::batch_dim()'],['../structgko_1_1batch__dim.html#a084efe247f49ff54a4156858991a2eb5',1,'gko::batch_dim::batch_dim(const size_type num_batch_items, const dim&lt; dimensionality, dimension_type &gt; &amp;common_size)']]],
  ['batch_5fdim_3c_202_20_3e_3',['batch_dim&lt; 2 &gt;',['../structgko_1_1batch__dim.html',1,'gko']]],
  ['batch_5flinop_5ffactory_5fevents_5fmask_4',['batch_linop_factory_events_mask',['../classgko_1_1log_1_1Logger.html#a3a6ea4ed2e7b25cd1ca869e4d3bdb07a',1,'gko::log::Logger']]],
  ['batchcg_20in_20ginkgo_5',['Example: using BatchCG in Ginkgo',['../classgko_1_1batch_1_1BatchLinOpFactory.html#autotoc_md71',1,'']]],
  ['batchconvergence_6',['BatchConvergence',['../classgko_1_1batch_1_1log_1_1BatchConvergence.html',1,'gko::batch::log']]],
  ['batched_20linear_20operator_20as_20a_20concept_7',['Batched Linear operator as a concept',['../group__BatchLinOp.html#batch_linop_concept',1,'']]],
  ['batched_20solver_20program_8',['The batched-solver program',['../batched_solver.html',1,'']]],
  ['batchlinop_9',['BatchLinOp',['../classgko_1_1batch_1_1BatchLinOp.html',1,'gko::batch::BatchLinOp'],['../group__BatchLinOp.html',1,'BatchLinOp']]],
  ['batchlinopfactory_10',['BatchLinOpFactory',['../classgko_1_1batch_1_1BatchLinOpFactory.html',1,'gko::batch']]],
  ['batchsolver_11',['BatchSolver',['../classgko_1_1batch_1_1solver_1_1BatchSolver.html',1,'gko::batch::solver']]],
  ['begin_12',['begin',['../structgko_1_1span.html#a54ff06eda27a98b62e83c7e9e7b6dcd7',1,'gko::span']]],
  ['benchmark_20options_13',['7: Available benchmark options',['../benchmarking_ginkgo.html#autotoc_md17',1,'']]],
  ['benchmarking_20overview_14',['4: Benchmarking overview',['../benchmarking_ginkgo.html#autotoc_md14',1,'']]],
  ['benchmarks_15',['Running the benchmarks',['../benchmarking_ginkgo.html',1,'']]],
  ['benchmarks_20manually_16',['3: Running benchmarks manually',['../benchmarking_ginkgo.html#autotoc_md13',1,'']]],
  ['best_20practice_20guidelines_17',['1: Ginkgo setup and best practice guidelines',['../benchmarking_ginkgo.html#autotoc_md11',1,'']]],
  ['bicg_18',['Bicg',['../classgko_1_1solver_1_1Bicg.html',1,'gko::solver']]],
  ['bicgstab_19',['Bicgstab',['../classgko_1_1batch_1_1solver_1_1Bicgstab.html',1,'gko::batch::solver::Bicgstab&lt; ValueType &gt;'],['../classgko_1_1solver_1_1Bicgstab.html',1,'gko::solver::Bicgstab&lt; ValueType &gt;']]],
  ['bind_5fto_5fcore_20',['bind_to_core',['../classgko_1_1machine__topology.html#a9a18cb07c0fcc866997c727abfac52d9',1,'gko::machine_topology']]],
  ['bind_5fto_5fcores_21',['bind_to_cores',['../classgko_1_1machine__topology.html#aa63dcb3e4080720109cf9e48bfc97f42',1,'gko::machine_topology']]],
  ['bind_5fto_5fpu_22',['bind_to_pu',['../classgko_1_1machine__topology.html#a9788d302561048fa91257f71ca9fa4be',1,'gko::machine_topology']]],
  ['bind_5fto_5fpus_23',['bind_to_pus',['../classgko_1_1machine__topology.html#a6c1579ec42001ec51ecb7102578bd932',1,'gko::machine_topology']]],
  ['bitwise_5fand_24',['bitwise_and',['../structgko_1_1accessor_1_1bitwise__and.html',1,'gko::accessor']]],
  ['bitwise_5fnot_25',['bitwise_not',['../structgko_1_1accessor_1_1bitwise__not.html',1,'gko::accessor']]],
  ['bitwise_5for_26',['bitwise_or',['../structgko_1_1accessor_1_1bitwise__or.html',1,'gko::accessor']]],
  ['bitwise_5fxor_27',['bitwise_xor',['../structgko_1_1accessor_1_1bitwise__xor.html',1,'gko::accessor']]],
  ['block_5fat_28',['block_at',['../classgko_1_1BlockOperator.html#a8ae64878f419a1719010efa49c660279',1,'gko::BlockOperator']]],
  ['block_5finterleaved_5fstorage_5fscheme_29',['block_interleaved_storage_scheme',['../structgko_1_1preconditioner_1_1block__interleaved__storage__scheme.html',1,'gko::preconditioner']]],
  ['block_5finterleaved_5fstorage_5fscheme_3c_20index_5ftype_20_3e_30',['block_interleaved_storage_scheme&lt; index_type &gt;',['../structgko_1_1preconditioner_1_1block__interleaved__storage__scheme.html',1,'gko::preconditioner']]],
  ['block_5foffset_31',['block_offset',['../structgko_1_1preconditioner_1_1block__interleaved__storage__scheme.html#ada09b37f171d433cc74818961fc6eccc',1,'gko::preconditioner::block_interleaved_storage_scheme']]],
  ['block_5fpointers_32',['block_pointers',['../structgko_1_1batch_1_1preconditioner_1_1Jacobi_1_1parameters__type.html#afd91913f62dc55b7173d41f6d6144961',1,'gko::batch::preconditioner::Jacobi::parameters_type::block_pointers'],['../structgko_1_1preconditioner_1_1Jacobi_1_1parameters__type.html#ad90b07202f15b6cd5c649f6b61480053',1,'gko::preconditioner::Jacobi::parameters_type::block_pointers']]],
  ['blockjacobi_20program_33',['The adaptiveprecision-blockjacobi program',['../adaptiveprecision_blockjacobi.html',1,'']]],
  ['blockoperator_34',['BlockOperator',['../classgko_1_1BlockOperator.html',1,'gko::BlockOperator'],['../classgko_1_1BlockOperator.html#acb8ff1788a332231a3e9f8199dec0d03',1,'gko::BlockOperator::BlockOperator(const BlockOperator &amp;other)'],['../classgko_1_1BlockOperator.html#a4066b33a9d42462429c76eea3f9532c1',1,'gko::BlockOperator::BlockOperator(BlockOperator &amp;&amp;other) noexcept']]],
  ['blocksizeerror_35',['BlockSizeError',['../classgko_1_1BlockSizeError.html',1,'gko::BlockSizeError&lt; IndexType &gt;'],['../classgko_1_1BlockSizeError.html#a861999cfafdd726814ef4bcd06734bd7',1,'gko::BlockSizeError::BlockSizeError()']]],
  ['both_5ffactors_36',['both_factors',['../structgko_1_1factorization_1_1Ic_1_1parameters__type.html#afb4c7814334072ab39c2e2b04925cdc4',1,'gko::factorization::Ic::parameters_type::both_factors'],['../structgko_1_1factorization_1_1ParIc_1_1parameters__type.html#abfa3c5afbc05b7c25b09ae225e6c966a',1,'gko::factorization::ParIc::parameters_type::both_factors']]],
  ['broadcast_37',['broadcast',['../classgko_1_1experimental_1_1mpi_1_1communicator.html#a95ea693d1ddc249215968d378e80dcc7',1,'gko::experimental::mpi::communicator']]],
  ['build_38',['build',['../classgko_1_1experimental_1_1factorization_1_1Cholesky.html#a154cada7f11335b0148b946e3b6ad85f',1,'gko::experimental::factorization::Cholesky::build()'],['../classgko_1_1experimental_1_1factorization_1_1Lu.html#a61cd8064ed1566c54912183bfeae5e5e',1,'gko::experimental::factorization::Lu::build()'],['../classgko_1_1preconditioner_1_1GaussSeidel.html#a7dbce0fc2e2e9a1eaca030a9f368b739',1,'gko::preconditioner::GaussSeidel::build()'],['../classgko_1_1preconditioner_1_1Sor.html#a23c746f50487fe2824c3957995645099',1,'gko::preconditioner::Sor::build()'],['../classgko_1_1experimental_1_1reorder_1_1Amd.html#a03fa10a26c275d6aa5e87c97836f3169',1,'gko::experimental::reorder::Amd::build()'],['../classgko_1_1experimental_1_1reorder_1_1Mc64.html#acf4ff0eb6edb11ea44b9745ece9ded65',1,'gko::experimental::reorder::Mc64::build()'],['../classgko_1_1experimental_1_1reorder_1_1Rcm.html#a6be4bed40dd659bc915f4320c6f1ab81',1,'gko::experimental::reorder::Rcm::build()']]],
  ['build_5ffrom_5fcontiguous_39',['build_from_contiguous',['../classgko_1_1experimental_1_1distributed_1_1Partition.html#acbc987df113d50d6cdf6d6b605a15860',1,'gko::experimental::distributed::Partition']]],
  ['build_5ffrom_5fglobal_5fsize_5funiform_40',['build_from_global_size_uniform',['../classgko_1_1experimental_1_1distributed_1_1Partition.html#a54bfa82bec475057cba794814342505e',1,'gko::experimental::distributed::Partition']]],
  ['build_5ffrom_5fmapping_41',['build_from_mapping',['../classgko_1_1experimental_1_1distributed_1_1Partition.html#ad17d1164a99bca5df2d2ec0eb5d79c2f',1,'gko::experimental::distributed::Partition']]],
  ['build_5fpartition_5ffrom_5flocal_5frange_42',['build_partition_from_local_range',['../namespacegko_1_1experimental_1_1distributed.html#ae0368295654a9d8455731832a88ffc8c',1,'gko::experimental::distributed']]],
  ['build_5fpartition_5ffrom_5flocal_5fsize_43',['build_partition_from_local_size',['../namespacegko_1_1experimental_1_1distributed.html#a6fff69d2898fefe193012da079a2fef0',1,'gko::experimental::distributed']]],
  ['build_5fsmoother_44',['build_smoother',['../namespacegko_1_1solver.html#ac565c4b95ad0c67492073d993a9170cc',1,'gko::solver::build_smoother(std::shared_ptr&lt; const LinOpFactory &gt; factory, size_type iteration=1, ValueType relaxation_factor=0.9)'],['../namespacegko_1_1solver.html#aadb962ce0b5566e83fcdb22dda6e3cf8',1,'gko::solver::build_smoother(std::shared_ptr&lt; const LinOp &gt; solver, size_type iteration=1, ValueType relaxation_factor=0.9)']]],
  ['building_45',['Building',['../install_ginkgo.html#autotoc_md0',1,'']]],
  ['building_20ginkgo_20in_20windows_46',['Building Ginkgo in Windows',['../install_ginkgo.html#autotoc_md1',1,'']]],
  ['building_20ginkgo_20with_20hip_20support_47',['Building Ginkgo with HIP support',['../install_ginkgo.html#autotoc_md2',1,'']]],
  ['by_20clangformat_48',['Other Code Formatting not handled by ClangFormat',['../contributing_guidelines.html#autotoc_md44',1,'']]],
  ['byte_5fsize_49',['byte_size',['../namespacegko.html#acae2e648052ec788bd8ba9e0192652a6',1,'gko']]]
];
